#!/usr/bin/python

import pdb

"""
  Routines, that convert itu channel to wavelength and frequency

"""

c = 299792458	 # speed of light 

############################################################################
def itu_2_frequency(itu_channel):
  """
  converts the <numpy.float64> ITU channel number to frequency
  """
  itu_frequency = (190 + (itu_channel/10))*1e12

  return (itu_frequency)

############################################################################
def itu_2_wavelength(itu_channel):
  """
  converts the <numpy.float64> ITU channel number to wavelength
  """
  itu_wavelength = (c/itu_2_frequency(itu_channel))

  return (itu_wavelength)

############################################################################
def frequency_2_itu(frequency):
  """
  converts the <numpy.float64> frequency to ITU channel number
  Note ITU channel number is rounded to one decimal to avoid long numbers
  due to small rounding errors in the input frequency value
  """
  itu_channel = ((frequency/1e12)-190)*10
  itu_channel = round(itu_channel,1) # round to 1 decimal

  return(itu_channel)

############################################################################
def wavelength_2_itu(wavelength):
  """
  converts the <numpy.float64> wavelength to ITU channel number
  Note ITU channel number is rounded to one decimal to avoid long numbers
  due to small rounding errors in the input wavelength value
  """
  
  itu_channel = frequency_2_itu(c/wavelength)
  itu_channel = round(itu_channel,1) # round to 1 decimal

  return(itu_channel)

############################################################################
def desired_freq_2_sfp_ch(desired_freq, first_freq, grid):
  """
  converts desired frequency into SFP channel number
  input:
  desired_freq  <int> The desired freqency in Hz
  first_freq    <int> Lasers First Frequency in Hz
                      Following SFF8690 Table 4-3 the Lasers First Frequency
                      can be read from I2C 0xA2 page 2 Addr 132-135.
  grid         	<int> Laser's minimum supported grid spacing in Hz
                      Following SFF8690 Table 4-3 the Lasers First Frequency
                      can be read from I2C 0xA2 page 2 Addr 140-141.

  return:
  sfp_ch        <int> The number to set in the tunable SFP to obtain the
                      desired frequency, according the the equation given
                      in SFF8690
  """
  
  return(int(1+(desired_freq - first_freq) / grid))
